@@ -53,6 +53,13 @@
 #endif
 #endif
 
+#ifdef __VISUALC__
+#define M_SQRT2 1.4142135623730950
+#define M_PI_2 1.5707963267948966
+#define M_LN2 0.69314718055994531
+#define M_1_PI 0.31830988618379067
+#endif
+
 #ifdef HP39
 #include <time.h>
 #define M_E 2.7182818284590452
@@ -79,6 +86,11 @@
 #undef HAVE_LONG_DOUBLE
 #endif
 
+#if defined __VISUALC__ 
+#undef BIGENDIAN
+#endif
+
+
 #ifdef RTOS_THREADX
 #define NO_STDEXCEPT 1
 #endif
@@ -567,15 +579,6 @@ inline float ffloor(float f1){
 #endif
 }
 inline float finv(float f1){ return 1/f1; }
-#if defined HAVE_TGAMMAF || defined __APPLE__ || defined EMCC || defined EMCC2 || defined NO_BSD 
-inline float fgamma(float f1){ return tgammaf(f1); }
-#else
-#if defined(__MINGW_H) || defined(VISUALC) || defined(FXCG)// FIXME gamma, not used
-inline float fgamma(float f1){ return f1; }
-#else
-inline float fgamma(float f1){ return gammaf(f1); } // or tgammaf(f1) on some versions of emscripten
-#endif
-#endif
 #ifdef FXCG
 inline float atan2f(float f1,float f2,int rad){ if (rad) return std::atan2(f1,f2); else return std::atan2(f1,f2)*180/3.14159265358979323846;}
 #else
